@@ -141,6 +141,9 @@ ISCSI_TGT = 'ISCSITarget'
 ISCSI_TGT_ID_KEY = 'iscsiTargetId'
 ISCSI_TGT_ID_METRICS = 'iSCSITargetId'
 ISCSI_TGT_INFO = 'iSCSITargetInfo'
+MV = 'MaskingView'
+MV_ID = 'maskingViewId'
+MV_INFO = 'maskingViewInfo'
 PG = 'PortGroup'
 PG_ID = 'portGroupId'
 PG_INFO = 'portGroupInfo'
